/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <vdr/plugin.h>
#include <vdr/tools.h>

#include "blacklist.h"
#include "tools.h"

#define BL_FILE "blacklist.conf"

#define BL_KEY(NID,TSID,SID) ((((uint64_t) NID) << 32) | (((uint64_t) TSID) << 16) | ((uint64_t) SID))


//////////////////////////////////////////////////////////////////////////////


Blacklist::Blacklist(void)
{
  if (!Load(cPlugin::ConfigDirectory("nascan"), BL_FILE))
    dprint(L_ERR, "Failed to load blacklist");
}


//----------------------------------------------------------------------------

bool Blacklist::Blacklisted(uint16_t nid, uint16_t tid, uint16_t sid) const
{
  std::set<uint64_t>::const_iterator itr = blist.find(BL_KEY(nid, tid, sid));
  return (itr != blist.end());
}


//----------------------------------------------------------------------------

void Blacklist::Add(uint16_t nid, uint16_t tid, uint16_t sid)
{
  blist.insert(BL_KEY(nid, tid, sid));
}


//----------------------------------------------------------------------------

bool Blacklist::Parse(const char* line)
{
  int nid = 0;
  int sid = 0;
  int tid = 0;      

  if (3 == sscanf(line, "%d :%d :%d ", &sid ,&nid ,&tid) && (sid && nid && tid)) 
  {
    blist.insert(BL_KEY(nid, tid, sid));
    return true;
  }

  return false;
}


//////////////////////////////////////////////////////////////////////////////



