/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <vdr/plugin.h>
#include <vdr/tools.h>

#include "names.h"
#include "tools.h"

#define NAMES_FILE "names.conf"

#define NAME_KEY(NID,TSID,SID) ((((uint64_t) NID) << 32) | (((uint64_t) TSID) << 16) | ((uint64_t) SID))


//////////////////////////////////////////////////////////////////////////////


ChannelNames::ChannelNames(void)
{
  if (!Load(cPlugin::ConfigDirectory("nascan"), NAMES_FILE))
    dprint(L_ERR, "Failed to load %s", NAMES_FILE);
}


//----------------------------------------------------------------------------

const char* ChannelNames::Name(uint16_t nid, uint16_t tid, uint16_t sid) const
{
  std::map<uint64_t, std::string>::const_iterator itr = names.find(NAME_KEY(nid, tid, sid));

  return (itr != names.end()) ? (*itr).second.c_str() : NULL;
}


//----------------------------------------------------------------------------

bool ChannelNames::Parse(const char* line)
{
  char* name = NULL;
  int nid = 0;
  int sid = 0;
  int tid = 0;      
      
  if (4 == sscanf(line, "%a[^:]:%d :%d :%d ", &name, &sid ,&nid ,&tid) && (name && sid && nid && tid)) 
  {
    names[NAME_KEY(nid, tid, sid)] = name;
    free(name);
    return true;
  }

  free(name);
  return false;
}


//////////////////////////////////////////////////////////////////////////////



