/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#ifndef __NASCAN_OSD_H
#define __NASCAN_OSD_H


#include <vdr/osdbase.h>

#include "pmtfilter.h"
#include "sdtfilter.h"
#include "nitfilter.h"
#include "names.h"
#include "configfile.h"


#define MAXSOURCES 32


//////////////////////////////////////////////////////////////////////////////


class ScanOsd : public cOsdMenu, public cThread, public ConfigFile
{
public:
  ScanOsd(void);
  virtual ~ScanOsd();
 
  virtual eOSState ProcessKey(eKeys Key);
 
protected:
  virtual void Action(void);
  virtual bool Parse(const char* line);
  
private:
  void AddLine(const char* Text, ...); 
  void UpdateLastLine(const char* Text);

  cChannel* GetInitial(int i) const;
  bool Tune(cDevice* device, const cChannel* c, int timeout);
  
  int sources[MAXSOURCES + 1];
  int numSources;
  int frequency[MAXSOURCES + 1];
  char polarization[MAXSOURCES + 1];
  int symbolRate[MAXSOURCES + 1];
  
  cList<TransponderSorter> transponderList;
  cList<ChannelSorter> channelList;

  bool needsUpdate;
  
  const char* dir;
  
  SdtFilter sdtFilter;
  NitFilter nitFilter;
  PmtFilter pmtFilter; 
  ChannelNames names;
};


//////////////////////////////////////////////////////////////////////////////


#endif // __NASCAN_OSD_H
